@@ -84,7 +84,7 @@
 #define KTEXTWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KTEXTWIDGETS_NO_DEPRECATED
-#  define KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
+#  define KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56c00
 #endif
 #ifdef KTEXTWIDGETS_NO_DEPRECATED_WARNINGS
 #  define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE KTEXTWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56b00
+#    define KTEXTWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56c00
 #  endif
 #endif
 
